@@ -5,7 +5,7 @@ try:
 except ImportError:
     raise RuntimeError("Please use pretix 2.7 or above to run this plugin!")
 
-__version__ = "1.0.0"
+__version__ = "2.0.0"
 
 
 class PluginApp(PluginConfig):
@@ -15,7 +15,7 @@ class PluginApp(PluginConfig):
     class PretixPluginMeta:
         name = gettext_lazy("Vaccination: Automatic scheduling of second dose")
         author = "pretix team"
-        description = gettext_lazy("Automatic scheduling of second dose after checkin")
+        description = gettext_lazy("Automatic scheduling of second dose")
         visible = True
         version = __version__
         category = "FEATURE"
